@@ -3,6 +3,8 @@
 #  cache.py
 """
 Caching functions for functions.
+
+.. seealso:: The `cachier project <https://pypi.org/project/cachier/>`_
 """
 #
 #  Copyright (c) 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -74,7 +76,6 @@ class Cache:
 				shutil.rmtree(self.cache_dir)
 				self.cache_dir.maybe_make()
 				for function in self.caches:
-					del self.caches[function]
 					self.caches[function] = {}
 			else:
 				function_name = func.__name__
